@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 """
-Copyright 2020 The Johns Hopkins University Applied Physics Laboratory.
+Copyright 2021 The Johns Hopkins University Applied Physics Laboratory.
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
@@ -30,7 +30,7 @@ from .executors.NetworkXExecutor import NetworkXExecutor
 from .executors.GrandIsoExecutor import GrandIsoExecutor
 from .executors.Neo4jExecutor import Neo4jExecutor
 
-__version__ = "0.8.0"
+__version__ = "0.10.0"
 
 DEFAULT_MOTIF_PARSER = ParserV2
 
@@ -63,7 +63,7 @@ class Motif:
             parser (dotmotif.parsers.Parser: DEFAULT_MOTIF_PARSER): The parser
                 to use to parse the document. Defaults to the v2 parser.
             exclude_automorphisms (bool: False): Whether to exclude automorphism
-                variants of the motif when rturning results.
+                variants of the motif when returning results.
             validators (List[Validator]): A list of dotmotif.Validators to use
                 when verifying the motif for correctness and executability.
 
@@ -119,7 +119,7 @@ class Motif:
 
         return self
 
-    def from_nx(self, graph: nx.DiGraph) -> "dotmotif":
+    def from_nx(self, graph: nx.DiGraph) -> "Motif":
         """
         Ingest directly from a graph.
 
@@ -197,7 +197,7 @@ class Motif:
         return fname
 
     @staticmethod
-    def load(fname: Union[str, IO[bytes]]) -> "dotmotif":
+    def load(fname: Union[str, IO[bytes]]) -> "Motif":
         """
         Load the motif from a file on disk.
 
@@ -215,6 +215,3 @@ class Motif:
         result = pickle.load(f)
         f.close()
         return result
-
-
-dotmotif = Motif
